@@ -198,7 +198,8 @@ def make_list(emails) :
 def parse_address_string(s) :
     import pyparsing as pp
 
-    host = pp.Combine(pp.delimitedList(pp.Word(pp.alphanums), '.', combine=True)).setParseAction(pp.downcaseTokens)
+    host = pp.Combine(pp.delimitedList(pp.Word(pp.alphanums), '.', combine=True))\
+                        .setParseAction(pp.pyparsing_common.downcaseTokens)
     email = pp.Combine(pp.Word(pp.alphanums) + "@" + host)
 
     name = pp.CharsNotIn(',<"') |  pp.dblQuotedString.setParseAction(pp.removeQuotes)
